@@ -6,6 +6,10 @@ from qualang_tools.bakery.randomized_benchmark import (
     find_revert_op,
     RBSequence,
 )
+from qualang_tools.config_tools.integration_weights_tools import (
+    convert_integration_weights,
+    compress_integration_weights,
+)
 
 __all__ = [
     "baking",
@@ -15,4 +19,6 @@ __all__ = [
     "RBSequence",
     "find_revert_op",
     "XEBOpsSingleQubit",
+    "convert_integration_weights",
+    "compress_integration_weights",
 ]
